from setuptools import setup, find_packages

setup(
    name='butils',
    version='0.0.3',
    keywords=('utils',),
    description='A useful utils package',
    license='MIT License',
    install_requires=[],

    author='bohanzhang',
    author_email='me@bohanzhang.com',

    packages=find_packages(),
)
